import { VDomModel } from '@jupyterlab/apputils';
import { escapeComments } from './utils';
export class BytecodeModel extends VDomModel {
    constructor() {
        super();
        this.handleKernelMessage = (msg) => {
            const msgType = msg.header.msg_type;
            const message = msg.content;
            switch (msgType) {
                case 'stream':
                    this._output = message.text;
                    this._error = '';
                    this.notify();
                    break;
                case 'error':
                    console.error(msg.content);
                    this._error = message.evalue;
                    this.notify();
                    break;
                default:
                    break;
            }
        };
        this._output = '';
        this._error = '';
        this._isLight = true;
    }
    formatKernelMessage(fileContent) {
        const escapedContent = escapeComments(fileContent);
        const code = ['import dis', `dis.dis("""${escapedContent}""")`].join('\n');
        return code;
    }
    notify() {
        this.stateChanged.emit(void 0);
    }
    get output() {
        return this._output;
    }
    get error() {
        return this._error;
    }
    get isLight() {
        return this._isLight;
    }
    set isLight(value) {
        this._isLight = value;
    }
    get selectedLines() {
        return this._selectedLines;
    }
    set selectedLines(lines) {
        this._selectedLines = lines;
        this.notify();
    }
}
